Index: /issm/trunk/src/c/DataSet/DataSet.cpp
===================================================================
--- /issm/trunk/src/c/DataSet/DataSet.cpp	(revision 4090)
+++ /issm/trunk/src/c/DataSet/DataSet.cpp	(revision 4091)
@@ -1050,32 +1050,2 @@
 }
 /*}}}*/
-/*FUNCTION DataSet::UpdateInputsFromVector{{{1*/
-void  DataSet::UpdateInputsFromVector(double* vec, int name, int type){
-
-	vector<Object*>::iterator object;
-	for ( object=objects.begin() ; object < objects.end(); object++ ){
-
-		(*object)->UpdateInputsFromVector(vec,name,type);
-	}
-}
-/*}}}*/
-/*FUNCTION DataSet::UpdateInputsFromVector{{{1*/
-void  DataSet::UpdateInputsFromVector(int* vec, int name, int type){
-
-	vector<Object*>::iterator object;
-	for ( object=objects.begin() ; object < objects.end(); object++ ){
-
-		(*object)->UpdateInputsFromVector(vec,name,type);
-	}
-}
-/*}}}*/
-/*FUNCTION DataSet::UpdateInputsFromVector{{{1*/
-void  DataSet::UpdateInputsFromVector(bool* vec, int name, int type){
-
-	vector<Object*>::iterator object;
-	for ( object=objects.begin() ; object < objects.end(); object++ ){
-
-		(*object)->UpdateInputsFromVector(vec,name,type);
-	}
-}
-/*}}}*/
Index: /issm/trunk/src/c/DataSet/DataSet.h
===================================================================
--- /issm/trunk/src/c/DataSet/DataSet.h	(revision 4090)
+++ /issm/trunk/src/c/DataSet/DataSet.h	(revision 4091)
@@ -68,7 +68,4 @@
 		void  SetSorting(int* in_sorted_ids,int* in_id_offsets);
 		void  Sort();
-		void  UpdateInputsFromVector(double* vector,int name, int type);
-		void  UpdateInputsFromVector(int* vector,int name, int type);
-		void  UpdateInputsFromVector(bool* vector,int name, int type);
 		int   RiftIsPresent();
 		int   MeltingIsPresent();
Index: /issm/trunk/src/c/Makefile.am
===================================================================
--- /issm/trunk/src/c/Makefile.am	(revision 4090)
+++ /issm/trunk/src/c/Makefile.am	(revision 4091)
@@ -436,6 +436,6 @@
 					./modules/GetVectorFromInputsx/GetVectorFromInputsx.h\
 					./modules/GetVectorFromInputsx/GetVectorFromInputsx.cpp\
-					./modules/UpdateInputsFromVectorx/UpdateInputsFromVectorx.h\
-					./modules/UpdateInputsFromVectorx/UpdateInputsFromVectorx.cpp\
+					./modules/InputUpdateFromVectorx/InputUpdateFromVectorx.h\
+					./modules/InputUpdateFromVectorx/InputUpdateFromVectorx.cpp\
 					./modules/UpdateGeometryx/UpdateGeometryx.h\
 					./modules/UpdateGeometryx/UpdateGeometryx.cpp\
@@ -959,6 +959,6 @@
 					./modules/GetVectorFromInputsx/GetVectorFromInputsx.h\
 					./modules/GetVectorFromInputsx/GetVectorFromInputsx.cpp\
-					./modules/UpdateInputsFromVectorx/UpdateInputsFromVectorx.h\
-					./modules/UpdateInputsFromVectorx/UpdateInputsFromVectorx.cpp\
+					./modules/InputUpdateFromVectorx/InputUpdateFromVectorx.h\
+					./modules/InputUpdateFromVectorx/InputUpdateFromVectorx.cpp\
 					./modules/UpdateGeometryx/UpdateGeometryx.h\
 					./modules/UpdateGeometryx/UpdateGeometryx.cpp\
Index: /issm/trunk/src/c/modules/CostFunctionx/CostFunctionx.cpp
===================================================================
--- /issm/trunk/src/c/modules/CostFunctionx/CostFunctionx.cpp	(revision 4090)
+++ /issm/trunk/src/c/modules/CostFunctionx/CostFunctionx.cpp	(revision 4091)
@@ -32,5 +32,8 @@
 
 	/*add surface area to elements :*/
-	elements->UpdateInputsFromVector(&S,SurfaceAreaEnum,ConstantEnum);
+	for(i=0;i<elements->Size();i++){
+		Element* element=(Element*)elements->GetObjectByOffset(i);
+		element->InputUpdateFromVector(&S,SurfaceAreaEnum,ConstantEnum);
+	}
 	
 	/*Compute cost function: */
Index: /issm/trunk/src/c/modules/Dux/Dux.cpp
===================================================================
--- /issm/trunk/src/c/modules/Dux/Dux.cpp	(revision 4090)
+++ /issm/trunk/src/c/modules/Dux/Dux.cpp	(revision 4091)
@@ -38,5 +38,8 @@
 
 	/*add surface area to elements :*/
-	elements->UpdateInputsFromVector(&S,SurfaceAreaEnum,ConstantEnum);
+	for(i=0;i<elements->Size();i++){
+		Element* element=(Element*)elements->GetObjectByOffset(i);
+		element->InputUpdateFromVector(&S,SurfaceAreaEnum,ConstantEnum);
+	}
 	
 	/*Get size of matrix: */
Index: /issm/trunk/src/c/modules/InputUpdateFromVectorx/InputUpdateFromVectorx.cpp
===================================================================
--- /issm/trunk/src/c/modules/InputUpdateFromVectorx/InputUpdateFromVectorx.cpp	(revision 4090)
+++ /issm/trunk/src/c/modules/InputUpdateFromVectorx/InputUpdateFromVectorx.cpp	(revision 4091)
@@ -24,21 +24,5 @@
 void InputUpdateFromVectorx( DataSet* elements,DataSet* nodes, DataSet* vertices, DataSet* loads, DataSet* materials, Parameters* parameters,double* vector, int NameEnum, int TypeEnum){
 
-	/*First, get elements and loads configured: */
-	elements->Configure(elements,loads, nodes,vertices, materials,parameters);
-	loads->Configure(elements, loads, nodes,vertices, materials,parameters);
-	nodes->Configure(elements, loads, nodes,vertices, materials,parameters);
-	parameters->Configure(elements,loads, nodes,vertices, materials,parameters);
-
-	/*Update elements, nodes, loads and materials from inputs: */
-	elements->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	nodes->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	vertices->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	loads->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	materials->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	parameters->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-
-}
-
-void InputUpdateFromVectorx( DataSet* elements,DataSet* nodes, DataSet* vertices, DataSet* loads, DataSet* materials, Parameters* parameters,int* vector, int NameEnum, int TypeEnum){
+	int i;
 
 	/*First, get elements and loads configured: */
@@ -49,14 +33,34 @@
 
 	/*Update elements, nodes, loads and materials from inputs: */
-	elements->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	nodes->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	vertices->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	loads->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	materials->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	parameters->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	for(i=0;i<elements->Size();i++){
+		Element* element=(Element*)elements->GetObjectByOffset(i);
+		element->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<nodes->Size();i++){
+		Node* node=(Node*)nodes->GetObjectByOffset(i);
+		node->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<vertices->Size();i++){
+		Vertex* vertex=(Vertex*)vertices->GetObjectByOffset(i);
+		vertex->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<loads->Size();i++){
+		Load* load=(Load*)loads->GetObjectByOffset(i);
+		load->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<materials->Size();i++){
+		Material* material=(Material*)materials->GetObjectByOffset(i);
+		material->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<parameters->Size();i++){
+		Param* parameter=(Param*)parameters->GetObjectByOffset(i);
+		parameter->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
 
 }
 
-void InputUpdateFromVectorx( DataSet* elements,DataSet* nodes, DataSet* vertices, DataSet* loads, DataSet* materials, Parameters* parameters,bool* vector, int NameEnum, int TypeEnum){
+void InputUpdateFromVectorx( DataSet* elements,DataSet* nodes, DataSet* vertices, DataSet* loads, DataSet* materials, Parameters* parameters,int* vector, int NameEnum, int TypeEnum){
+	
+	int i;
 
 	/*First, get elements and loads configured: */
@@ -67,10 +71,65 @@
 
 	/*Update elements, nodes, loads and materials from inputs: */
-	elements->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	nodes->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	vertices->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	loads->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	materials->InputUpdateFromVector(vector,NameEnum,TypeEnum);
-	parameters->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	for(i=0;i<elements->Size();i++){
+		Element* element=(Element*)elements->GetObjectByOffset(i);
+		element->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<nodes->Size();i++){
+		Node* node=(Node*)nodes->GetObjectByOffset(i);
+		node->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<vertices->Size();i++){
+		Vertex* vertex=(Vertex*)vertices->GetObjectByOffset(i);
+		vertex->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<loads->Size();i++){
+		Load* load=(Load*)loads->GetObjectByOffset(i);
+		load->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<materials->Size();i++){
+		Material* material=(Material*)materials->GetObjectByOffset(i);
+		material->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<parameters->Size();i++){
+		Param* parameter=(Param*)parameters->GetObjectByOffset(i);
+		parameter->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
 
 }
+
+void InputUpdateFromVectorx( DataSet* elements,DataSet* nodes, DataSet* vertices, DataSet* loads, DataSet* materials, Parameters* parameters,bool* vector, int NameEnum, int TypeEnum){
+
+	int i;
+
+	/*First, get elements and loads configured: */
+	elements->Configure(elements,loads, nodes,vertices, materials,parameters);
+	loads->Configure(elements, loads, nodes,vertices, materials,parameters);
+	nodes->Configure(elements, loads, nodes,vertices, materials,parameters);
+	parameters->Configure(elements,loads, nodes,vertices, materials,parameters);
+
+	/*Update elements, nodes, loads and materials from inputs: */
+	for(i=0;i<elements->Size();i++){
+		Element* element=(Element*)elements->GetObjectByOffset(i);
+		element->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<nodes->Size();i++){
+		Node* node=(Node*)nodes->GetObjectByOffset(i);
+		node->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<vertices->Size();i++){
+		Vertex* vertex=(Vertex*)vertices->GetObjectByOffset(i);
+		vertex->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<loads->Size();i++){
+		Load* load=(Load*)loads->GetObjectByOffset(i);
+		load->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<materials->Size();i++){
+		Material* material=(Material*)materials->GetObjectByOffset(i);
+		material->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+	for(i=0;i<parameters->Size();i++){
+		Param* parameter=(Param*)parameters->GetObjectByOffset(i);
+		parameter->InputUpdateFromVector(vector,NameEnum,TypeEnum);
+	}
+}
Index: /issm/trunk/src/c/modules/Misfitx/Misfitx.cpp
===================================================================
--- /issm/trunk/src/c/modules/Misfitx/Misfitx.cpp	(revision 4090)
+++ /issm/trunk/src/c/modules/Misfitx/Misfitx.cpp	(revision 4091)
@@ -32,5 +32,8 @@
 
 	/*add surface area to elements :*/
-	elements->UpdateInputsFromVector(&S,SurfaceAreaEnum,ConstantEnum);
+	for(i=0;i<elements->Size();i++){
+		Element* element=(Element*)elements->GetObjectByOffset(i);
+		element->InputUpdateFromVector(&S,SurfaceAreaEnum,ConstantEnum);
+	}
 
 	/*Compute Misfit: */
Index: /issm/trunk/src/c/modules/PenaltyConstraintsx/RiftConstraints.cpp
===================================================================
--- /issm/trunk/src/c/modules/PenaltyConstraintsx/RiftConstraints.cpp	(revision 4090)
+++ /issm/trunk/src/c/modules/PenaltyConstraintsx/RiftConstraints.cpp	(revision 4091)
@@ -308,5 +308,8 @@
 
 	/*feed max_penetration to inputs: */
-	loads->UpdateInputsFromVector(&max_penetration,MaxPenetrationEnum,ConstantEnum);
+	for(i=0;i<loads->Size();i++){
+		Load* load=(Load*)loads->GetObjectByOffset(i);
+		load->InputUpdateFromVector(&max_penetration,MaxPenetrationEnum,ConstantEnum);
+	}
 }
 
Index: /issm/trunk/src/c/modules/UpdateGeometryx/UpdateGeometryx.cpp
===================================================================
--- /issm/trunk/src/c/modules/UpdateGeometryx/UpdateGeometryx.cpp	(revision 4090)
+++ /issm/trunk/src/c/modules/UpdateGeometryx/UpdateGeometryx.cpp	(revision 4091)
@@ -106,7 +106,7 @@
 
 	/*Put back into inputs:*/
-	UpdateInputsFromVectorx( elements,nodes, vertices,loads, materials,  parameters,vec_newthickness,ThicknessEnum,VertexEnum); //clobber existing thickness input with new one
-	UpdateInputsFromVectorx( elements,nodes, vertices,loads, materials,  parameters,vec_bed,BedEnum,VertexEnum); 
-	UpdateInputsFromVectorx( elements,nodes, vertices,loads, materials,  parameters,vec_surface,SurfaceEnum,VertexEnum); 
+	InputUpdateFromVectorx( elements,nodes, vertices,loads, materials,  parameters,vec_newthickness,ThicknessEnum,VertexEnum); //clobber existing thickness input with new one
+	InputUpdateFromVectorx( elements,nodes, vertices,loads, materials,  parameters,vec_bed,BedEnum,VertexEnum); 
+	InputUpdateFromVectorx( elements,nodes, vertices,loads, materials,  parameters,vec_surface,SurfaceEnum,VertexEnum); 
 
 	/*Free ressources:*/
Index: /issm/trunk/src/c/modules/modules.h
===================================================================
--- /issm/trunk/src/c/modules/modules.h	(revision 4090)
+++ /issm/trunk/src/c/modules/modules.h	(revision 4091)
@@ -31,5 +31,5 @@
 #include "./InputUpdateFromSolutionx/InputUpdateFromSolutionx.h"
 #include "./InputUpdateFromDakotax/InputUpdateFromDakotax.h"
-#include "./UpdateInputsFromVectorx/UpdateInputsFromVectorx.h"
+#include "./InputUpdateFromVectorx/InputUpdateFromVectorx.h"
 #include "./UpdateGeometryx/UpdateGeometryx.h"
 #include "./UpdateVertexPositionsx/UpdateVertexPositionsx.h"
Index: /issm/trunk/src/c/objects/Constraints/Rgb.h
===================================================================
--- /issm/trunk/src/c/objects/Constraints/Rgb.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Constraints/Rgb.h	(revision 4091)
@@ -35,7 +35,7 @@
 		int    Id(); 
 		int    MyRank();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Constraints/Spc.h
===================================================================
--- /issm/trunk/src/c/objects/Constraints/Spc.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Constraints/Spc.h	(revision 4091)
@@ -39,7 +39,7 @@
 		double GetValue();
 		Object* copy();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/DofVec.h
===================================================================
--- /issm/trunk/src/c/objects/DofVec.h	(revision 4090)
+++ /issm/trunk/src/c/objects/DofVec.h	(revision 4091)
@@ -47,7 +47,7 @@
 		int   MyRank();
 		int   Size();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ElementResults/BeamVertexElementResult.h
===================================================================
--- /issm/trunk/src/c/objects/ElementResults/BeamVertexElementResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ElementResults/BeamVertexElementResult.h	(revision 4091)
@@ -38,7 +38,7 @@
 		int   EnumType();
 		
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ElementResults/DoubleElementResult.h
===================================================================
--- /issm/trunk/src/c/objects/ElementResults/DoubleElementResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ElementResults/DoubleElementResult.h	(revision 4091)
@@ -40,7 +40,7 @@
 		int   EnumType();
 
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ElementResults/PentaVertexElementResult.h
===================================================================
--- /issm/trunk/src/c/objects/ElementResults/PentaVertexElementResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ElementResults/PentaVertexElementResult.h	(revision 4091)
@@ -39,7 +39,7 @@
 		int   EnumType();
 		
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ElementResults/SingVertexElementResult.h
===================================================================
--- /issm/trunk/src/c/objects/ElementResults/SingVertexElementResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ElementResults/SingVertexElementResult.h	(revision 4091)
@@ -38,7 +38,7 @@
 		int   EnumType();
 		
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ElementResults/TriaVertexElementResult.h
===================================================================
--- /issm/trunk/src/c/objects/ElementResults/TriaVertexElementResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ElementResults/TriaVertexElementResult.h	(revision 4091)
@@ -38,7 +38,7 @@
 		int   EnumType();
 		
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Elements/Beam.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Beam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Beam.h	(revision 4091)
@@ -55,7 +55,7 @@
 		Object* copy();
 		void  SetClone(int* minranks);
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Elements/Penta.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Penta.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Penta.h	(revision 4091)
@@ -180,7 +180,7 @@
 		void  InputUpdateFromSolutionBalancedthickness2( double* solutiong);
 		void  InputUpdateFromSolutionBalancedvelocities( double* solutiong);
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Elements/Sing.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Sing.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Sing.h	(revision 4091)
@@ -55,7 +55,7 @@
 		void  SetClone(int* minranks);
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Elements/Tria.h
===================================================================
--- /issm/trunk/src/c/objects/Elements/Tria.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Tria.h	(revision 4091)
@@ -158,7 +158,7 @@
 		void  InputUpdateFromSolutionBalancedthickness2( double* solution);
 		void  InputUpdateFromSolutionBalancedvelocities( double* solution);
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/ExternalResults/BoolExternalResult.h
===================================================================
--- /issm/trunk/src/c/objects/ExternalResults/BoolExternalResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ExternalResults/BoolExternalResult.h	(revision 4091)
@@ -55,7 +55,7 @@
 		int   MyRank();
 
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ExternalResults/DoubleExternalResult.h
===================================================================
--- /issm/trunk/src/c/objects/ExternalResults/DoubleExternalResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ExternalResults/DoubleExternalResult.h	(revision 4091)
@@ -55,7 +55,7 @@
 		int   MyRank();
 
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ExternalResults/DoubleVecExternalResult.h
===================================================================
--- /issm/trunk/src/c/objects/ExternalResults/DoubleVecExternalResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ExternalResults/DoubleVecExternalResult.h	(revision 4091)
@@ -54,7 +54,7 @@
 		int   MyRank();
 
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ExternalResults/IntExternalResult.h
===================================================================
--- /issm/trunk/src/c/objects/ExternalResults/IntExternalResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ExternalResults/IntExternalResult.h	(revision 4091)
@@ -55,7 +55,7 @@
 		int   MyRank();
 
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ExternalResults/PetscVecExternalResult.h
===================================================================
--- /issm/trunk/src/c/objects/ExternalResults/PetscVecExternalResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ExternalResults/PetscVecExternalResult.h	(revision 4091)
@@ -53,7 +53,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/ExternalResults/StringExternalResult.h
===================================================================
--- /issm/trunk/src/c/objects/ExternalResults/StringExternalResult.h	(revision 4090)
+++ /issm/trunk/src/c/objects/ExternalResults/StringExternalResult.h	(revision 4091)
@@ -54,7 +54,7 @@
 		int   MyRank();
 
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Inputs/BeamVertexInput.h
===================================================================
--- /issm/trunk/src/c/objects/Inputs/BeamVertexInput.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Inputs/BeamVertexInput.h	(revision 4091)
@@ -36,7 +36,7 @@
 		Object* copy();
 		int   EnumType();
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Inputs/BoolInput.h
===================================================================
--- /issm/trunk/src/c/objects/Inputs/BoolInput.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Inputs/BoolInput.h	(revision 4091)
@@ -36,7 +36,7 @@
 		Object* copy();
 		int   EnumType();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Inputs/DoubleInput.h
===================================================================
--- /issm/trunk/src/c/objects/Inputs/DoubleInput.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Inputs/DoubleInput.h	(revision 4091)
@@ -38,7 +38,7 @@
 		int   EnumType();
 
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Inputs/IntInput.h
===================================================================
--- /issm/trunk/src/c/objects/Inputs/IntInput.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Inputs/IntInput.h	(revision 4091)
@@ -36,7 +36,7 @@
 		Object* copy();
 		int   EnumType();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Inputs/PentaVertexInput.h
===================================================================
--- /issm/trunk/src/c/objects/Inputs/PentaVertexInput.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Inputs/PentaVertexInput.h	(revision 4091)
@@ -35,7 +35,7 @@
 		Object* copy();
 		int   EnumType();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Inputs/SingVertexInput.h
===================================================================
--- /issm/trunk/src/c/objects/Inputs/SingVertexInput.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Inputs/SingVertexInput.h	(revision 4091)
@@ -35,7 +35,7 @@
 		Object* copy();
 		int   EnumType();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Inputs/TriaVertexInput.h
===================================================================
--- /issm/trunk/src/c/objects/Inputs/TriaVertexInput.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Inputs/TriaVertexInput.h	(revision 4091)
@@ -36,7 +36,7 @@
 		Object* copy();
 		int   EnumType();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Loads/Icefront.h
===================================================================
--- /issm/trunk/src/c/objects/Loads/Icefront.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Loads/Icefront.h	(revision 4091)
@@ -49,7 +49,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Loads/Numericalflux.h
===================================================================
--- /issm/trunk/src/c/objects/Loads/Numericalflux.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Loads/Numericalflux.h	(revision 4091)
@@ -44,7 +44,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Loads/Pengrid.h
===================================================================
--- /issm/trunk/src/c/objects/Loads/Pengrid.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Loads/Pengrid.h	(revision 4091)
@@ -50,7 +50,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Loads/Penpair.h
===================================================================
--- /issm/trunk/src/c/objects/Loads/Penpair.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Loads/Penpair.h	(revision 4091)
@@ -41,7 +41,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void  UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void  InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void  InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Loads/Riftfront.h
===================================================================
--- /issm/trunk/src/c/objects/Loads/Riftfront.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Loads/Riftfront.h	(revision 4091)
@@ -59,7 +59,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Materials/Material.h
===================================================================
--- /issm/trunk/src/c/objects/Materials/Material.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Materials/Material.h	(revision 4091)
@@ -26,7 +26,7 @@
 		virtual void  Demarshall(char** pmarshalled_dataset)=0;
 		virtual void  UpdateFromInputs(void* inputs)=0;
-		virtual void  UpdateInputsFromVector(double* vector, int name, int type)=0;
-		virtual void  UpdateInputsFromVector(int* vector, int name, int type)=0;
-		virtual void  UpdateInputsFromVector(bool* vector, int name, int type)=0;
+		virtual void  InputUpdateFromVector(double* vector, int name, int type)=0;
+		virtual void  InputUpdateFromVector(int* vector, int name, int type)=0;
+		virtual void  InputUpdateFromVector(bool* vector, int name, int type)=0;
 		virtual void  InputUpdateFromSolution(double* solution)=0;
 		
Index: /issm/trunk/src/c/objects/Materials/Matice.h
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matice.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Materials/Matice.h	(revision 4091)
@@ -44,7 +44,7 @@
 		double GetB();
 		double GetN();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Materials/Matpar.h
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matpar.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Materials/Matpar.h	(revision 4091)
@@ -56,7 +56,7 @@
 		double GetMeltingPoint();
 		Object* copy();
-		void   UpdateInputsFromVector(double* vector, int name, int type);
-		void   UpdateInputsFromVector(int* vector, int name, int type);
-		void   UpdateInputsFromVector(bool* vector, int name, int type);
+		void   InputUpdateFromVector(double* vector, int name, int type);
+		void   InputUpdateFromVector(int* vector, int name, int type);
+		void   InputUpdateFromVector(bool* vector, int name, int type);
 		void   InputUpdateFromConstant(double constant, int name);
 		void   InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Node.h
===================================================================
--- /issm/trunk/src/c/objects/Node.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Node.h	(revision 4091)
@@ -53,7 +53,7 @@
 		int   MyRank(void);
 		void  SetVertexDof(int in_dof);
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Object.h
===================================================================
--- /issm/trunk/src/c/objects/Object.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Object.h	(revision 4091)
@@ -25,7 +25,7 @@
 		virtual int   Enum()=0;
 		virtual Object* copy()=0;
-		virtual void  UpdateInputsFromVector(double* vector, int name, int type)=0;
-		virtual void  UpdateInputsFromVector(int* vector, int name, int type)=0;
-		virtual void  UpdateInputsFromVector(bool* vector, int name, int type)=0;
+		virtual void  InputUpdateFromVector(double* vector, int name, int type)=0;
+		virtual void  InputUpdateFromVector(int* vector, int name, int type)=0;
+		virtual void  InputUpdateFromVector(bool* vector, int name, int type)=0;
 		virtual void  InputUpdateFromConstant(double constant, int name)=0;
 		virtual void  InputUpdateFromConstant(int constant, int name)=0;
Index: /issm/trunk/src/c/objects/Params/BoolParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/BoolParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/BoolParam.h	(revision 4091)
@@ -50,7 +50,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/DoubleMatParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/DoubleMatParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/DoubleMatParam.h	(revision 4091)
@@ -53,7 +53,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/DoubleParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/DoubleParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/DoubleParam.h	(revision 4091)
@@ -51,7 +51,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/DoubleVecParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/DoubleVecParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/DoubleVecParam.h	(revision 4091)
@@ -51,7 +51,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/IntParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/IntParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/IntParam.h	(revision 4091)
@@ -51,7 +51,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/PetscMatParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/PetscMatParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/PetscMatParam.h	(revision 4091)
@@ -51,7 +51,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/PetscVecParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/PetscVecParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/PetscVecParam.h	(revision 4091)
@@ -51,7 +51,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/StringArrayParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/StringArrayParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/StringArrayParam.h	(revision 4091)
@@ -53,7 +53,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/Params/StringParam.h
===================================================================
--- /issm/trunk/src/c/objects/Params/StringParam.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/StringParam.h	(revision 4091)
@@ -51,7 +51,7 @@
 		int   MarshallSize();
 		int   MyRank();
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/objects/SolPar.h
===================================================================
--- /issm/trunk/src/c/objects/SolPar.h	(revision 4090)
+++ /issm/trunk/src/c/objects/SolPar.h	(revision 4091)
@@ -39,7 +39,7 @@
 		int   Enum();
 		Object* copy();
-		void    UpdateInputsFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
-		void    UpdateInputsFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(double* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(int* vector, int name, int type){ISSMERROR("Not implemented yet!");}
+		void    InputUpdateFromVector(bool* vector, int name, int type){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(double constant, int name){ISSMERROR("Not implemented yet!");}
 		void    InputUpdateFromConstant(int constant, int name){ISSMERROR("Not implemented yet!");}
Index: /issm/trunk/src/c/objects/Vertex.h
===================================================================
--- /issm/trunk/src/c/objects/Vertex.h	(revision 4090)
+++ /issm/trunk/src/c/objects/Vertex.h	(revision 4091)
@@ -50,7 +50,7 @@
 		void  UpdateFromDakota(void* vinputs);
 		void  UpdatePosition(double* thickness,double* bed);
-		void  UpdateInputsFromVector(double* vector, int name, int type);
-		void  UpdateInputsFromVector(int* vector, int name, int type);
-		void  UpdateInputsFromVector(bool* vector, int name, int type);
+		void  InputUpdateFromVector(double* vector, int name, int type);
+		void  InputUpdateFromVector(int* vector, int name, int type);
+		void  InputUpdateFromVector(bool* vector, int name, int type);
 		void  InputUpdateFromConstant(double constant, int name);
 		void  InputUpdateFromConstant(int constant, int name);
Index: /issm/trunk/src/c/solutions/gradient_core.cpp
===================================================================
--- /issm/trunk/src/c/solutions/gradient_core.cpp	(revision 4090)
+++ /issm/trunk/src/c/solutions/gradient_core.cpp	(revision 4091)
@@ -55,6 +55,6 @@
 
 	/*plug back into inputs: */
-	UpdateInputsFromVectorx( femmodel-> elements,femmodel-> nodes, femmodel-> vertices,femmodel-> loads, femmodel-> materials,  femmodel->parameters,gradient,GradientEnum,VertexEnum);
-	UpdateInputsFromVectorx( femmodel-> elements,femmodel-> nodes, femmodel-> vertices,femmodel-> loads, femmodel-> materials,  femmodel->parameters,old_gradient,OldGradientEnum,VertexEnum);
+	InputUpdateFromVectorx( femmodel-> elements,femmodel-> nodes, femmodel-> vertices,femmodel-> loads, femmodel-> materials,  femmodel->parameters,gradient,GradientEnum,VertexEnum);
+	InputUpdateFromVectorx( femmodel-> elements,femmodel-> nodes, femmodel-> vertices,femmodel-> loads, femmodel-> materials,  femmodel->parameters,old_gradient,OldGradientEnum,VertexEnum);
 
 	/*Free ressources and return:*/
Index: /issm/trunk/src/c/solvers/solver_thermal_nonlinear.cpp
===================================================================
--- /issm/trunk/src/c/solvers/solver_thermal_nonlinear.cpp	(revision 4090)
+++ /issm/trunk/src/c/solvers/solver_thermal_nonlinear.cpp	(revision 4091)
@@ -111,5 +111,5 @@
 		
 		//Update inputs using new solution:
-		UpdateInputsFromVectorx( fem->elements,fem->nodes, fem->vertices, fem->loads, fem->materials, fem->parameters,tg,TemperatureEnum,VertexEnum);
+		InputUpdateFromVectorx( fem->elements,fem->nodes, fem->vertices, fem->loads, fem->materials, fem->parameters,tg,TemperatureEnum,VertexEnum);
 		InputUpdateFromSolutionx(fem->elements,fem->nodes, fem->vertices, fem->loads, fem->materials, fem->parameters,tg);
 

Index: /issm/trunk/src/c/objects/Elements/Beam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Beam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Beam.cpp	(revision 4091)
@@ -610,6 +610,6 @@
 }
 /*}}}1*/
-/*FUNCTION Beam::UpdateInputsFromVector(double* vector, int name, int type);{{{1*/
-void  Beam::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION Beam::InputUpdateFromVector(double* vector, int name, int type);{{{1*/
+void  Beam::InputUpdateFromVector(double* vector, int name, int type){
 
 	/*Check that name is an element input*/
@@ -637,11 +637,11 @@
 }
 /*}}}*/
-/*FUNCTION Beam::UpdateInputsFromVector(int* vector, int name, int type);{{{1*/
-void  Beam::UpdateInputsFromVector(int* vector, int name, int type){
-	ISSMERROR(" not supported yet!");
-}
-/*}}}*/
-/*FUNCTION Beam::UpdateInputsFromVector(bool* vector, int name, int type);{{{1*/
-void  Beam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Beam::InputUpdateFromVector(int* vector, int name, int type);{{{1*/
+void  Beam::InputUpdateFromVector(int* vector, int name, int type){
+	ISSMERROR(" not supported yet!");
+}
+/*}}}*/
+/*FUNCTION Beam::InputUpdateFromVector(bool* vector, int name, int type);{{{1*/
+void  Beam::InputUpdateFromVector(bool* vector, int name, int type){
 	ISSMERROR(" not supported yet!");
 }
Index: /issm/trunk/src/c/objects/Elements/Penta.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Penta.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Penta.cpp	(revision 4091)
@@ -4804,6 +4804,6 @@
 }
 /*}}}*/
-/*FUNCTION Penta::UpdateInputsFromVector(double* vector, int name, int type);{{{1*/
-void  Penta::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION Penta::InputUpdateFromVector(double* vector, int name, int type);{{{1*/
+void  Penta::InputUpdateFromVector(double* vector, int name, int type){
 
 	/*Check that name is an element input*/
@@ -4832,11 +4832,11 @@
 }
 /*}}}*/
-/*FUNCTION Penta::UpdateInputsFromVector(int* vector, int name, int type);{{{1*/
-void  Penta::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION Penta::InputUpdateFromVector(int* vector, int name, int type);{{{1*/
+void  Penta::InputUpdateFromVector(int* vector, int name, int type){
 	ISSMERROR(" not supported yet!");
 }
 /*}}}*/
-/*FUNCTION Penta::UpdateInputsFromVector(bool* vector, int name, int type);{{{1*/
-void  Penta::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Penta::InputUpdateFromVector(bool* vector, int name, int type);{{{1*/
+void  Penta::InputUpdateFromVector(bool* vector, int name, int type){
 	ISSMERROR(" not supported yet!");
 }
Index: /issm/trunk/src/c/objects/Elements/Sing.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Sing.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Sing.cpp	(revision 4091)
@@ -424,6 +424,6 @@
 }
 /*}}}1*/
-/*FUNCTION Sing::UpdateInputsFromVector(double* vector, int name, int type);{{{1*/
-void  Sing::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION Sing::InputUpdateFromVector(double* vector, int name, int type);{{{1*/
+void  Sing::InputUpdateFromVector(double* vector, int name, int type){
 
 	/*Check that name is an element input*/
@@ -449,11 +449,11 @@
 }
 /*}}}*/
-/*FUNCTION Sing::UpdateInputsFromVector(int* vector, int name, int type);{{{1*/
-void  Sing::UpdateInputsFromVector(int* vector, int name, int type){
-	ISSMERROR(" not supported yet!");
-}
-/*}}}*/
-/*FUNCTION Sing::UpdateInputsFromVector(bool* vector, int name, int type);{{{1*/
-void  Sing::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Sing::InputUpdateFromVector(int* vector, int name, int type);{{{1*/
+void  Sing::InputUpdateFromVector(int* vector, int name, int type){
+	ISSMERROR(" not supported yet!");
+}
+/*}}}*/
+/*FUNCTION Sing::InputUpdateFromVector(bool* vector, int name, int type);{{{1*/
+void  Sing::InputUpdateFromVector(bool* vector, int name, int type){
 	ISSMERROR(" not supported yet!");
 }
Index: /issm/trunk/src/c/objects/Elements/Tria.cpp
===================================================================
--- /issm/trunk/src/c/objects/Elements/Tria.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Elements/Tria.cpp	(revision 4091)
@@ -4963,6 +4963,6 @@
 }
 /*}}}*/
-/*FUNCTION Tria::UpdateInputsFromVector(double* vector, int name, int type);{{{1*/
-void  Tria::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION Tria::InputUpdateFromVector(double* vector, int name, int type);{{{1*/
+void  Tria::InputUpdateFromVector(double* vector, int name, int type){
 
 	/*Check that name is an element input*/
@@ -4991,11 +4991,11 @@
 }
 /*}}}*/
-/*FUNCTION Tria::UpdateInputsFromVector(int* vector, int name, int type);{{{1*/
-void  Tria::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION Tria::InputUpdateFromVector(int* vector, int name, int type);{{{1*/
+void  Tria::InputUpdateFromVector(int* vector, int name, int type){
 	ISSMERROR(" not supported yet!");
 }
 /*}}}*/
-/*FUNCTION Tria::UpdateInputsFromVector(bool* vector, int name, int type);{{{1*/
-void  Tria::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Tria::InputUpdateFromVector(bool* vector, int name, int type);{{{1*/
+void  Tria::InputUpdateFromVector(bool* vector, int name, int type){
 	ISSMERROR(" not supported yet!");
 }
Index: /issm/trunk/src/c/objects/Loads/Icefront.cpp
===================================================================
--- /issm/trunk/src/c/objects/Loads/Icefront.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Loads/Icefront.cpp	(revision 4091)
@@ -1346,16 +1346,16 @@
 }
 /*}}}*/
-/*FUNCTION Icefront::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  Icefront::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION Icefront::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  Icefront::InputUpdateFromVector(double* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION Icefront::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  Icefront::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION Icefront::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  Icefront::InputUpdateFromVector(int* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION Icefront::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  Icefront::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Icefront::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  Icefront::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Loads/Pengrid.cpp
===================================================================
--- /issm/trunk/src/c/objects/Loads/Pengrid.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Loads/Pengrid.cpp	(revision 4091)
@@ -733,16 +733,16 @@
 }
 /*}}}1*/
-/*FUNCTION Pengrid::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  Pengrid::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION Pengrid::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  Pengrid::InputUpdateFromVector(double* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION Pengrid::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  Pengrid::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION Pengrid::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  Pengrid::InputUpdateFromVector(int* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION Pengrid::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  Pengrid::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Pengrid::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  Pengrid::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Materials/Matice.cpp
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matice.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Materials/Matice.cpp	(revision 4091)
@@ -428,16 +428,16 @@
 }
 /*}}}*/
-/*FUNCTION Matice::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  Matice::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION Matice::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  Matice::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION Matice::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  Matice::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Matice::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  Matice::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  Matice::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matice::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  Matice::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Materials/Matpar.cpp
===================================================================
--- /issm/trunk/src/c/objects/Materials/Matpar.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Materials/Matpar.cpp	(revision 4091)
@@ -279,16 +279,16 @@
 }
 /*}}}1*/
-/*FUNCTION Matpar::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void   Matpar::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION Matpar::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void   Matpar::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION Matpar::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void   Matpar::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Matpar::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void   Matpar::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void   Matpar::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Matpar::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void   Matpar::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Node.cpp
===================================================================
--- /issm/trunk/src/c/objects/Node.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Node.cpp	(revision 4091)
@@ -837,18 +837,18 @@
 }
 /*}}}*/
-/*FUNCTION Node::UpdateInputsFromVector(double* vector, int name, int type){{{2*/
-void  Node::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION Node::InputUpdateFromVector(double* vector, int name, int type){{{2*/
+void  Node::InputUpdateFromVector(double* vector, int name, int type){
 
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION Node::UpdateInputsFromVector(int* vector, int name, int type){{{2*/
-void  Node::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION Node::InputUpdateFromVector(int* vector, int name, int type){{{2*/
+void  Node::InputUpdateFromVector(int* vector, int name, int type){
 
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION Node::UpdateInputsFromVector(bool* vector, int name, int type){{{2*/
-void  Node::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Node::InputUpdateFromVector(bool* vector, int name, int type){{{2*/
+void  Node::InputUpdateFromVector(bool* vector, int name, int type){
 
 	/*Nothing updated yet*/
Index: /issm/trunk/src/c/objects/Params/BoolParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/BoolParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/BoolParam.cpp	(revision 4091)
@@ -144,16 +144,16 @@
 /*}}}*/
 
-/*FUNCTION BoolParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  BoolParam::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION BoolParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  BoolParam::InputUpdateFromVector(double* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION BoolParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  BoolParam::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION BoolParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  BoolParam::InputUpdateFromVector(int* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION BoolParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  BoolParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION BoolParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  BoolParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/DoubleMatParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/DoubleMatParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/DoubleMatParam.cpp	(revision 4091)
@@ -200,16 +200,16 @@
 /*}}}*/
 
-/*FUNCTION DoubleMatParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  DoubleMatParam::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION DoubleMatParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  DoubleMatParam::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION DoubleMatParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  DoubleMatParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION DoubleMatParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  DoubleMatParam::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION DoubleMatParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  DoubleMatParam::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION DoubleMatParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  DoubleMatParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/DoubleParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/DoubleParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/DoubleParam.cpp	(revision 4091)
@@ -166,16 +166,16 @@
 /*}}}*/
 
-/*FUNCTION DoubleParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  DoubleParam::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION DoubleParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  DoubleParam::InputUpdateFromVector(double* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION DoubleParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  DoubleParam::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION DoubleParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  DoubleParam::InputUpdateFromVector(int* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION DoubleParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  DoubleParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION DoubleParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  DoubleParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/DoubleVecParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/DoubleVecParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/DoubleVecParam.cpp	(revision 4091)
@@ -210,16 +210,16 @@
 /*}}}*/
 
-/*FUNCTION DoubleVecParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  DoubleVecParam::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION DoubleVecParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  DoubleVecParam::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION DoubleVecParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  DoubleVecParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION DoubleVecParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  DoubleVecParam::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION DoubleVecParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  DoubleVecParam::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION DoubleVecParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  DoubleVecParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/IntParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/IntParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/IntParam.cpp	(revision 4091)
@@ -145,16 +145,16 @@
 /*}}}*/
 
-/*FUNCTION IntParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  IntParam::UpdateInputsFromVector(double* vector, int name, int type){
+/*FUNCTION IntParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  IntParam::InputUpdateFromVector(double* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION IntParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  IntParam::UpdateInputsFromVector(int* vector, int name, int type){
+/*FUNCTION IntParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  IntParam::InputUpdateFromVector(int* vector, int name, int type){
 	/*Nothing updated yet*/
 }
 /*}}}*/
-/*FUNCTION IntParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  IntParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION IntParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  IntParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/PetscMatParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/PetscMatParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/PetscMatParam.cpp	(revision 4091)
@@ -227,16 +227,16 @@
 /*}}}*/
 
-/*FUNCTION PetscMatParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  PetscMatParam::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION PetscMatParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  PetscMatParam::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION PetscMatParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  PetscMatParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION PetscMatParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  PetscMatParam::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION PetscMatParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  PetscMatParam::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION PetscMatParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  PetscMatParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/PetscVecParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/PetscVecParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/PetscVecParam.cpp	(revision 4091)
@@ -221,16 +221,16 @@
 /*}}}*/
 
-/*FUNCTION PetscVecParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  PetscVecParam::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION PetscVecParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  PetscVecParam::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION PetscVecParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  PetscVecParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION PetscVecParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  PetscVecParam::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION PetscVecParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  PetscVecParam::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION PetscVecParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  PetscVecParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/StringArrayParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/StringArrayParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/StringArrayParam.cpp	(revision 4091)
@@ -250,16 +250,16 @@
 /*}}}*/
 
-/*FUNCTION StringArrayParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  StringArrayParam::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION StringArrayParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  StringArrayParam::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION StringArrayParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  StringArrayParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION StringArrayParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  StringArrayParam::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION StringArrayParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  StringArrayParam::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION StringArrayParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  StringArrayParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Params/StringParam.cpp
===================================================================
--- /issm/trunk/src/c/objects/Params/StringParam.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Params/StringParam.cpp	(revision 4091)
@@ -176,16 +176,16 @@
 /*}}}*/
 
-/*FUNCTION StringParam::UpdateInputsFromVector(double* vector, int name, int type) {{{1*/
-void  StringParam::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION StringParam::UpdateInputsFromVector(int* vector, int name, int type) {{{1*/
-void  StringParam::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION StringParam::UpdateInputsFromVector(bool* vector, int name, int type) {{{1*/
-void  StringParam::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION StringParam::InputUpdateFromVector(double* vector, int name, int type) {{{1*/
+void  StringParam::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION StringParam::InputUpdateFromVector(int* vector, int name, int type) {{{1*/
+void  StringParam::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION StringParam::InputUpdateFromVector(bool* vector, int name, int type) {{{1*/
+void  StringParam::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }
Index: /issm/trunk/src/c/objects/Vertex.cpp
===================================================================
--- /issm/trunk/src/c/objects/Vertex.cpp	(revision 4090)
+++ /issm/trunk/src/c/objects/Vertex.cpp	(revision 4091)
@@ -183,16 +183,16 @@
 /*}}}*/
 
-/*FUNCTION Vertex::UpdateInputsFromVector(double* vector, int name, int type) {{{2*/
-void  Vertex::UpdateInputsFromVector(double* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION Vertex::UpdateInputsFromVector(int* vector, int name, int type) {{{2*/
-void  Vertex::UpdateInputsFromVector(int* vector, int name, int type){
-	/*Nothing updated yet*/
-}
-/*}}}*/
-/*FUNCTION Vertex::UpdateInputsFromVector(bool* vector, int name, int type) {{{2*/
-void  Vertex::UpdateInputsFromVector(bool* vector, int name, int type){
+/*FUNCTION Vertex::InputUpdateFromVector(double* vector, int name, int type) {{{2*/
+void  Vertex::InputUpdateFromVector(double* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Vertex::InputUpdateFromVector(int* vector, int name, int type) {{{2*/
+void  Vertex::InputUpdateFromVector(int* vector, int name, int type){
+	/*Nothing updated yet*/
+}
+/*}}}*/
+/*FUNCTION Vertex::InputUpdateFromVector(bool* vector, int name, int type) {{{2*/
+void  Vertex::InputUpdateFromVector(bool* vector, int name, int type){
 	/*Nothing updated yet*/
 }